==> ATGoogleMaps-0.4.1.tar.gz: ATGoogleMaps/content/GMarker.py <==
"""A Google Marker type"""

__author__  = '''takanori <takanori@takanory.net>'''
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo

try:
  from Products.LinguaPlone.public import *
except ImportError:
  # No multilingual support
  from Products.Archetypes.public import *

from Products.ATContentTypes.content.base import ATCTContent
from Products.ATContentTypes.content.document import ATDocumentSchema
from Products.ATContentTypes.content.document import ATDocument
from Products.ATContentTypes.content.schemata import ATContentTypeSchema
from Products.ATContentTypes.content.schemata import finalizeATCTSchema

from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder

from Products.validation.validators.RangeValidator import RangeValidator
from Products.validation.config import validation
from Products.validation import V_REQUIRED

validation.register(RangeValidator('checkLatitude',
                                   minval=-90.0, maxval=90.0))
validation.register(RangeValidator('checkLongitude',
                                   minval=-180.0, maxval=180.0))

#from Products.Archetypes.atapi import *

from Products.ATGoogleMaps.config import *

GMarkerSchema = ATDocumentSchema.copy() + Schema((
    StringField('address',
        widget=IntegerWidget(
            label='Address',
            label_msgid='label_address',
            description_msgid='help_address',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    StringField('phone',
        widget=IntegerWidget(
            label='Phone',
            label_msgid='label_phone',
            description_msgid='help_phone',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    StringField('url',
        widget=IntegerWidget(
            label='URL',
            label_msgid='label_url',
            description_msgid='help_url',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    StringField('imageurl',
        widget=IntegerWidget(
            label='Image URL',
            label_msgid='label_image_url',
            description_msgid='help_image_url',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    FloatField('latitude',
        required=True,
        validators=(('checkLatitude', V_REQUIRED),),
        widget=DecimalWidget(
            label='Latitude',
            label_msgid='label_latitude',
            description_msgid='help_latitude',
            i18n_domain='googlemaps',
            size=12,
        )
    ),
    
    FloatField('longitude',
        required=True,
        validators=(('checkLongitude', V_REQUIRED),),
        widget=DecimalWidget(
            label='Longitude',
            label_msgid='label_longitude',
            description_msgid='help_longitude',
            i18n_domain='googlemaps',
            size=12,
        )
    ),

),
)

#Finalize schema definition
finalizeATCTSchema(GMarkerSchema)

class GMarker(ATDocument):
    """Google Marker"""
    
    schema          = GMarkerSchema

    content_icon    = 'gmarker_icon.gif'
    portal_type     = 'GMarker'
    meta_type       = 'GMarker'
    archetype_name  = 'GMarker'
    default_view    = 'gmarker_view'
    immediate_view  = 'gmarker_view'
    suppl_views     = ()
    typeDescription = 'Google marker document'
    typeDescMsgId   = 'gmarker_description_edit'

    global_allow    = 0

    # Get the standard actions (tabs)
    #actions = ATCTContent.actions

    # Make sure we get title-to-id generation when an object is created
    _at_rename_after_creation = True

registerType(GMarker, PROJECTNAME)

==> ATGoogleMaps-0.5.1.tar.gz: ATGoogleMaps/content/GMarker.py <==
"""A Google Marker type"""

__author__  = '''takanori <takanori@takanory.net>'''
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo

try:
  from Products.LinguaPlone.public import *
except ImportError:
  # No multilingual support
  from Products.Archetypes.public import *

from Products.ATContentTypes.content.base import ATCTContent
from Products.ATContentTypes.content.document import ATDocumentSchema
from Products.ATContentTypes.content.document import ATDocument
from Products.ATContentTypes.content.schemata import ATContentTypeSchema
from Products.ATContentTypes.content.schemata import finalizeATCTSchema

from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder

#from Products.Archetypes.atapi import *

from Products.ATGoogleMaps.config import *
from Products.ATGoogleMaps.field import LatLngField
from Products.ATGoogleMaps.widget import LatLngWidget

GMarkerSchema = ATDocumentSchema.copy() + Schema((
    StringField('address',
        widget=IntegerWidget(
            label='Address',
            label_msgid='label_address',
            description_msgid='help_address',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    StringField('phone',
        widget=IntegerWidget(
            label='Phone',
            label_msgid='label_phone',
            description_msgid='help_phone',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    StringField('url',
        widget=IntegerWidget(
            label='URL',
            label_msgid='label_url',
            description_msgid='help_url',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    StringField('imageurl',
        widget=IntegerWidget(
            label='Image URL',
            label_msgid='label_image_url',
            description_msgid='help_image_url',
            i18n_domain='googlemaps',
            size=30,
        )
    ),
    
    LatLngField('point',
        required=True,
        default_method='getGMapCenter',
        widget=LatLngWidget(
            label='Point',
            label_msgid='label_point',
            description='Point of this marker.',
            description_msgid='help_point',
            i18n_domain='googlemaps',
            size=12,
        )
    ),

),
)

#Finalize schema definition
finalizeATCTSchema(GMarkerSchema)

class GMarker(ATDocument):
    """Google Marker"""
    
    schema          = GMarkerSchema

    content_icon    = 'gmarker_icon.gif'
    portal_type     = 'GMarker'
    meta_type       = 'GMarker'
    archetype_name  = 'GMarker'
    default_view    = 'gmarker_view'
    immediate_view  = 'gmarker_view'
    suppl_views     = ()
    typeDescription = 'Google marker document'
    typeDescMsgId   = 'description_edit_gmarker'

    global_allow    = 0

    # Get the standard actions (tabs)
    #actions = ATCTContent.actions

    # Make sure we get title-to-id generation when an object is created
    _at_rename_after_creation = True

    # default point value from parent GMap center
    def getGMapCenter(self):
        latlng = {'latitude': '0,0', 'longitude': '0,0'}
        try:
            latlng = self.aq_parent.getCenter()
        except:
            pass
        return latlng

registerType(GMarker, PROJECTNAME)
